#!/bin/bash
#
#######################################################################################
#
# Program Name: getdata_msg.sh
#
# Purpose: Get input imagery for MSG ($age minutes ago of current)
#        --- Fetch MSG imagery to make a multi-spectral AREA file, and
#          put it to LD/MSG_IMG. If it fails to do so, return value is -1
#
# Usage: getdata_msg.sh [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script start to run.
#
# Prerequisite: export age
#
# Called by: proc_msg.sh
#
# Description: Fetch $age (e.g. 30) minutes age of current MSG imagery to generate a multi-
#              spectral AREA file, and then put it to LD/MSG_IMG. Steps in this script includes:
#             1. Set time range for data to be processed.
#             2. Fetch 5 band MSG imagery within the time range to local dataset.
#             3. Combine the five band into one multi-band AREA file by calling gimiglue,
#                then put it to LD/MSG_IMG.
#
# Scripts called: set_app_env.sh 
#
# Program called: gimiglue
#
# Change History:
# 98/02/03 started
# 98/03/17 add GOES-9
# 98/07/28 Remove *.drv
# 98/09/03 Activate GOES-WEST SH. Increase search range to +/- 14 min.
# 99/10/09 Switch from ORA to GER/GWR.
# 00/09/17 Separate processing at 15 & 45 minutes.
# 00/10/02 Check -l flag for log file 
# ???????? Adapt for Linux ; use areaSpecs
# 03/03/03 Adapt to cope with goes-12 / band6
# ???????? modified for MSG
# 02/24/2009  M. Fan  (PSGS)
#         1) Add comment blocks
#         2) Set directories and  environment variables by calling set_app_env.sh
#         3) Change LD/MSG to LD/MSG_IMG to fit to new configure.
#
#######################################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#----------------------------------------------------------------
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
                 datestring=`date -u +%j.%H%M` 
                 filename="$filename.$datestring.log"
                 exec >> $LOGDIR/$filename   2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done



echo "================================================================="
#echo "`date -u` start $progname"	# time stamp
echo "`date -u` start $scriptname"       # time stamp


## Set time reference for data to be processed
#  -- want $age minutes ago data
##           >> need an exported variable age <<<
#age=30
#----------------------------------------------
date=$(   date +%Y%j  -u -d"$age minutes ago" )
hour=$(   date +%H    -u -d"$age minutes ago" )
minute=$( date +%M    -u -d"$age minutes ago" )


## Set time range $WHEN (see below) for data to be processed.
#               -----------------------------
#               MSG - FULL DISK
#               -----------------------------
#               Data comes at HH:0,15,30,45
#               Download (hh-1):30 data at hh:00
#----------------------------------------------------------------
quarter_hour=$( expr  $minute / 15 )
let min101=100+15*$quarter_hour
let min102=100+15*$quarter_hour+5
min1=$( echo $min101 |cut -c2-3)
min2=$( echo $min102 |cut -c2-3)

echo "minute=$minute"
echo "quarter_hour=$quarter_hour"
echo "min1=$min1"
echo "min2=$min2"


WHEN=" DAY=$date  TIME=$hour:$min1 $hour:$min2 "

echo "MSG image between   $hour:$min1 and $hour:$min2 on date $date"


# Check if we already have this image
# If it already existed,exit.Ootherwise
#  continue the processing
#--------------------------------------
imglist.k  LD/MSG_IMG.ALL    $WHEN   >/dev/null 2>&1
if  [ $?  -eq 0 ] 
then
     echo " Already have MSG imagery for $WHEN ; exiting $0"
     exit 
fi

# Remove transition files
#------------------------
imgdel.k LD/A.0091 098


#   Copy the five band data  
#-------------------------------------------
#PARMS="SIZE=SAME"
PARMS=" LATLON=0  0     SIZE=3500 3500"

echo "	imgcopy.k   MSG/MSGLOB04I	LD/A.0092  $WHEN   $PARMS   "
	imgcopy.k   MSG/MSGLOB04I	LD/A.0092  $WHEN   $PARMS 
	imgcopy.k   MSG/MSGLOB05WV	LD/A.0093  $WHEN   $PARMS    
	imgcopy.k   MSG/MSGLOB09I	LD/A.0094  $WHEN   $PARMS    
	imgcopy.k   MSG/MSGLOB10I	LD/A.0095  $WHEN   $PARMS    
	imgcopy.k   MSG/MSGLOB02V	LD/A.0091  $WHEN   SIZE=SAME

echo "Got Meteosat imagery  at `date -u`"
 
#  Average visible data to 4-km resolution  
#---------------------------------------------
#@###	avgimi.k 1090 090 4


#  Combine the five band into one AREA-file -- calling gimiglue
#--------------------------------------------------------------
name0=$AREADIR/AREA009
InList=`echo $name0"2" $name0"1" $name0"3" $name0"4" $name0"5"`
OutFile=$AREADIR/AREA0098
rm -f $OutFile

#GIMIGLUE=$HOME/mcidas/src_msg/gimiglue_code/gimiglue
GIMIGLUE=gimiglue

	$GIMIGLUE   $OutFile  $InList


#OutFile2=$AREADIR/AREA12$hour

# delete garbage in and print error message
#---------------------------------------------
if [ $? -ne 0 ]
then
  echo "Error in gimiglue for $OutFile"
fi
imglist.k  LD/A.0090  0098
if [ $? -ne 0 ]
then
  echo "Error Code $?  in imglist for $OutFile"
  rm -f $OutFile
fi
# if Nonextistent or zero-sized outfile  $OutFile, exit the program with -1
if [ ! -s $OutFile ]
then
  rm -f $OutFile
  echo "Nonextistent or zero-sized outfile  $OutFile"
  echo "Exit getdata_ program with return value of -1"
  echo " End $scriptname at `date -u` " 
  exit -1
fi

# copy to area loop:  LD/MSG_IMG
#--------------------------------------------
imglist.k LD/A.98
imglist.k LD/MSG_IMG 

#let outnum=3200+4*$hour+$quarter_hour
imgcopy.k  LD/A.0098  LD/MSG_IMG    BAND=ALL SIZE=SAME



echo "`date -u` done copying data"
echo " End $scriptname at `date -u` "   # time stamp
echo " "
echo "================================================================="

#
###############################################################
# MSGGLOB01V    Latest MSG-1 band 1 0.635 um REALTIME
# MSGGLOB02V    Latest MSG-1 band 2 0.81 um REALTIME
# MSGGLOB03I    Latest MSG-1 band 3 1.64 um REALTIME
# MSGGLOB04I    Latest MSG-1 band 4 3.92 um REALTIME
# MSGGLOB05WV   Latest MSG-1 band 5 6.25 um REALTIME
# MSGGLOB06WV   Latest MSG-1 band 6 7.35 um REALTIME
# MSGGLOB07I    Latest MSG-1 band 7 8.7 um REALTIME
# MSGGLOB08I    Latest MSG-1 band 8 9.66 um REALTIME
# MSGGLOB09I    Latest MSG-1 band 9 10.8 um REALTIME
# MSGGLOB10I    Latest MSG-1 band 10 12.0 um REALTIME
# MSGGLOB11I    Latest MSG-1 band 11 13.4 um REALTIME
# MSGGLOB12V    Latest MSG-1 band 12 0.7 um REALTIME
#
# MSGLOB01V     24 hours of MSG Band 1
