#!/bin/bash
#
#######################################################################################
#
# Program Name: getdata_mtsat.sh
#
# Purpose: Get input imagery for MTSAT (the hour of $age minutes ago of current)
#       --- Fetch MTSAT imagery to make a multi-spectral AREA file, and
#          put it to LD/MTSAT_IMG.  If it fails to do so, return value is -1
#
# Usage: getdata_mtsat.sh [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script  start to run.
#
# Prerequisite: export age
#
# Called by: proc_mtsat.sh
#
# Description: Fetch $age (e.g. 60) minutes age of current MTSAT imagery to generate a multi-
#              spectral AREA file, and then put it to LD/MTSAT_IMG. Steps in this script includes:
#             1. Set time range for data to be processed.
#             2. Fetch 5 band MTSAT imagery within the time range to local dataset.
#             3. Average visible data to 4-km resolution and
#                combine the five band into one multi-band AREA file by calling gimiglue,
#                then put it to LD/MTSAT_IMG.
#
# Scripts called: set_app_env.sh 
#
# Program called: avgimi,  gimiglue
#
# Change History:
# 98/02/03 started
# 98/03/17 add GOES-9
# 98/07/28 Remove *.drv
# 98/09/03 Activate GOES-WEST SH. Increase search range to +/- 14 min.
# 99/10/09 Switch from ORA to GER/GWR.
# 00/09/17 Separate processing at 15 & 45 minutes.
# 00/10/02 Check -l flag for log file
# ???????? Adapt for Linux ; use areaSpecs
# 03/03/03 Adapt to cope with goes-12 / band6
# ???????? Modified for MTSAT
# 03/24/2009    M. Fan  (PSGS)
#         1) Add comment blocks
#         2) Set directories and  environment variables by calling set_app_env.sh
#         3) Change LD/MTSAT to LD/MTSAT_IMG to consistent to new configure.
#         --- modified from iprevious version getdata_mtsat.sh and 2009 version of getdata_msg.sh
#
#######################################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
export scriptname=$( basename $0 )

# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#----------------------------------------------------------------
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
                 datestring=`date -u +%j.%H%M` 
                 filename="$filename.$datestring.log"
                 exec >> $LOGDIR/$filename   2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done



echo "================================================================="
#echo "`date -u` start $progname"	# time stamp
echo "`date -u` start $scriptname"       # time stamp


## Set time reference for data to be processed
#  -- want $age minutes ago data
##           >> need an exported variable age <<<
#age=60
#----------------------------------------------
date=$(   date +%Y%j  -u -d"$age minutes ago" )
hour=$(   date +%H    -u -d"$age minutes ago" )
#minute=$( date +%M    -u -d"$age minutes ago" )


## Set time range $WHEN (see below) for data to be processed.
####                -----------------------------
####                MSG - FULL DISK
####                -----------------------------
####                Data comes at HH:0,15,30,45
####                Download (hh-1):30 data at hh:00
#               -----------------------------
#               MTSAT - FULL DISK
#               -----------------------------
#               Data comes at HH:30
#               Download (hh-1):30 data
#----------------------------------------------------------------

    min1=25
    min2=35

WHEN=" DAY=$date  TIME=$hour:$min1 $hour:$min2 "

echo "MTSAT image at $WHEN"


# Check if we already have this image
# If it already existed, exit. Otherwise
#  continue the processing
#--------------------------------------
imglist.k  LD/MTSAT_IMG.ALL    $WHEN   >/dev/null 2>&1
if  [ $?  -eq 0 ]
then
     echo " Already have MTSAT imagery for $WHEN ; exiting $0"
     exit
fi

# Remove transition files
#---------------------------
imgdel.k LD/A.0990 998


#  Copy the five band data  
#------------------------------------------------------------------
echo "  imgcopy.k   MTS/MTGLOB04I2      LD/A.0992  $WHEN   SIZE=SAME   "
        imgcopy.k   MTS/MTGLOB04I2      LD/A.0992  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB04I3      LD/A.0993  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB04I4      LD/A.0994  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB04I5      LD/A.0995  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB01V       LD/A.1990  $WHEN   SIZE=SAME

echo "Got MTSAT imagery  at `date -u`"
 

#  Average visible data to 4-km resolution  
#-----------------------------------------
        avgimi.k 1990 991 4
        imgdel.k LD/A.1990


## Combine the five band into one AREA-file: calling gimiglue 
#-----------------------------------------------------
name0=$AREADIR/AREA099
InList=`echo $name0"2" $name0"1" $name0"3" $name0"4" $name0"5"`

OutFile="${name0}8"

OutDSN=LD/A.0998

rm -f $OutFile

    gimiglue $OutFile  $InList
    rc1=$?

# delete garbage in and print error message
#---------------------------------------------
if [ $? -ne 0 ]
then
  echo "Error in gimiglue for $OutFile"
fi
imglist.k   LD/A.0990 0998
if [ $? -ne 0 ]
then
  echo "Error Code $?  in imglist for $OutFile"
  rm -f $OutFile
fi
# if Nonextistent or zero-sized outfile  $OutFile, exit the program with -1
if [ ! -s $OutFile ]
then
  rm -f $OutFile
  echo "Nonextistent or zero-sized outfile  $OutFile"
  echo "Exit getdata_ program with return value of -1"
  echo " End $scriptname at `date -u` " 
  exit -1
fi

# copy to area loop:  LD/MTSAT_IMG
#--------------------------------------------
imglist.k ${OutDSN}
imglist.k LD/MTSAT_IMG

imgcopy.k  ${OutDSN}  LD/MTSAT_IMG   SIZE=ALL


echo "`date -u` done copying data"
echo " End $scriptname at `date -u` "   # time stamp
echo " "
echo "================================================================="

